@@ -223,7 +223,7 @@ class mysql(object):
 				duplicate_str+=f' `{x}`=a.`{x}`,'
 			duplicate_str=duplicate_str[:-1]
 		return self.execute(f''' insert {ignore} `{table}`({key}) values {values[:-1]} {duplicate_str}''')
-	def update(self,where,data,table=None):
+	def update(self,data,where,table=None):
 		'''where can be str or dict'''
 		table=self.table if table is None else table
 		where=self._split_dict(where,'and') if isinstance(where,dict) else where
